package Evo::W::Eval;
use Carp 'croak';
use Evo '-Eval *', '-Export *';


sub w_eval_run : Export {
  my $catch = shift or croak "Pass catch function";
  sub {
    my $next = shift;
    sub {
      my $call = eval_want(wantarray, @_, $next);
      return $call->result if $call;
      $catch->($@);
      return;
    };
  };
}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Evo::W::Eval

=head1 VERSION

version 0.0173

=head1 AUTHOR

alexbyk.com

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by alexbyk.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
